#!/usr/bin/env bash
set -ex
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

source $(pwd)/config/configuration
source /deployment/deploy/helpers/run_command.sh
source /deployment/deploy/helpers/print_line.sh

export ART_SAAS=${ART_SAAS:-cb-docker-prod-local.usw1.packages.broadcom.com}
export SERVICE_NAME=$( echo $SERVICE_NAME | tr "." _ )

IMAGE_TAG=${IMAGE_TAG:-"${ART_SAAS}/cbd/${SERVICE_NAME}"}

printp "BUILDING IMAGE"

DOCKER_VARS=
DOCKER_ARGS=

if [ -f $(pwd)/hooks/pre_build_hook.sh ]; then
    . $(pwd)/hooks/pre_build_hook.sh
fi

if [ -f $(pwd)/config/docker_vars ]; then
    DOCKER_VARS=$(eval echo -e `<$(pwd)/config/docker_vars`)
    DOCKER_ARGS=$(run_deploy_command build_docker_vars $DOCKER_VARS)
fi

docker build -t $SERVICE_NAME \
       --build-arg pypiUser=${USW1_ACCESS_ID} --build-arg pypiToken=${USW1_ACCESS_TOKEN} \
       $DOCKER_ARGS \
       -f $(pwd)/docker/Dockerfile \
       --pull \
       $(pwd)
REPO_TAG=${IMAGE_TAG}
if [[ "$REPO_TAG" != *":"* ]]; then
  REPO_TAG=${IMAGE_TAG}:${LABEL_TAG_PREFIX}latest
fi
docker tag $SERVICE_NAME:latest $REPO_TAG
docker rmi $SERVICE_NAME:latest

if [ -f $(pwd)/hooks/post_build_hook.sh ]; then
    $(pwd)/hooks/post_build_hook.sh
fi
